Index — cdist 4.8.1 documentation

# Index

Symbols | C | H

## Symbols

--remote-copy REMOTE_COPY command line option --remote-exec REMOTE_EXEC command line option -4, --force-ipv4 command line option -6, --force-ipv6 command line option -a, --all command line option, [1], [2], [3] -A, --all-tagged command line option -b, --beta command line option, [1], [2], [3], [4], [5] -C CACHE_PATH_PATTERN, --cache-path-pattern CACHE_PATH_PATTERN command line option -c CONF_DIR, --conf-dir CONF_DIR command line option -f HOSTFILE, --file HOSTFILE command line option, [1], [2], [3], [4], [5] -g CONFIG_FILE, --config-file CONFIG_FILE command line option, [1], [2], [3], [4], [5] -h, --help command line option -H, --host-only command line option -I INVENTORY_DIR, --inventory INVENTORY_DIR command line option, [1], [2], [3], [4], [5] -i MANIFEST, --initial-manifest MANIFEST command line option -j [JOBS], --jobs [JOBS] command line option | -l LOGLEVEL, --log-level LOGLEVEL command line option -n, --dry-run command line option -o OUT_PATH, --out-dir OUT_PATH command line option -p [HOST_MAX], --parallel [HOST_MAX] command line option -q, --quiet command line option -R [{tar,tgz,tbz2,txz}], --use-archiving [{tar,tgz,tbz2,txz}] command line option -r REMOTE_OUT_PATH, --remote-out-dir REMOTE_OUT_PATH command line option -s SHELL, --shell SHELL command line option -S, --disable-saving-output-streams command line option -s, --sequential command line option -T TAGFILE, --tag-file TAGFILE command line option, [1] -t TAGLIST, --taglist TAGLIST command line option, [1] -t, --tag command line option, [1] -v, --verbose command line option -V, --version command line option

## C

command line option --remote-copy REMOTE_COPY --remote-exec REMOTE_EXEC -4, --force-ipv4 -6, --force-ipv6 -A, --all-tagged -C CACHE_PATH_PATTERN, --cache-path-pattern CACHE_PATH_PATTERN -H, --host-only -I INVENTORY_DIR, --inventory INVENTORY_DIR, [1], [2], [3], [4], [5] -R [{tar,tgz,tbz2,txz}], --use-archiving [{tar,tgz,tbz2,txz}] -S, --disable-saving-output-streams -T TAGFILE, --tag-file TAGFILE, [1] -V, --version -a, --all, [1], [2], [3] -b, --beta, [1], [2], [3], [4], [5] -c CONF_DIR, --conf-dir CONF_DIR -f HOSTFILE, --file HOSTFILE, [1], [2], [3], [4], [5] -g CONFIG_FILE, --config-file CONFIG_FILE, [1], [2], [3], [4], [5] -h, --help -i MANIFEST, --initial-manifest MANIFEST -j [JOBS], --jobs [JOBS] -l LOGLEVEL, --log-level LOGLEVEL -n, --dry-run -o OUT_PATH, --out-dir OUT_PATH -p [HOST_MAX], --parallel [HOST_MAX] -q, --quiet -r REMOTE_OUT_PATH, --remote-out-dir REMOTE_OUT_PATH -s SHELL, --shell SHELL -s, --sequential -t TAGLIST, --taglist TAGLIST, [1] -t, --tag, [1] -v, --verbose host, [1], [2], [3], [4]

## H

host command line option, [1], [2], [3], [4]